==> fcitx5_5.0.14.1.orig.tar.xz: fcitx5-5.0.14.1/README.md <==
Next generation of fcitx
==========================
Fcitx 5 is a generic input method framework released under LGPL-2.1+.

[![Jenkins Build Status](https://img.shields.io/jenkins/s/https/jenkins.fcitx-im.org/job/fcitx5.svg)](https://jenkins.fcitx-im.org/job/fcitx5/)
[![Coverity Scan Status](https://img.shields.io/coverity/scan/9063.svg)](https://scan.coverity.com/projects/fcitx-fcitx5)
[![Documentation](https://codedocs.xyz/fcitx/fcitx5.svg)](https://codedocs.xyz/fcitx/fcitx5/)

* Wiki: [https://fcitx-im.org/](https://fcitx-im.org/)
  - Registration require explicit approval due to the spam, please send an email to the mail list if you do not get approved.
* Discussion:
  - [fcitx [at] googlegroups.com](https://groups.google.com/g/fcitx)
  - [https://github.com/fcitx/fcitx5/discussions](https://github.com/fcitx/fcitx5/discussions)
  - Telegram: https://fcitx-im.org/telegram/captcha.html
  - IRC: [#fcitx [at] libera.chat](https://web.libera.chat/?channels=#fcitx)
* Bug report: [https://github.com/fcitx/fcitx5/issues](https://github.com/fcitx/fcitx5/issues)
  - You can always report any fcitx 5 issue here, it might be transfer to other repos later.
* Translation: [https://www.transifex.com/fcitx/](https://www.transifex.com/fcitx/)
  - Do not send pull request for translation updates.
  - The translation will be automatically pushed to git repository nightly, but not vice versa. 

[![Packaging status](https://repology.org/badge/vertical-allrepos/fcitx5.svg)](https://repology.org/project/fcitx5/versions)

==> fcitx5_5.1.12.orig.tar.xz: fcitx5-5.1.12/README.md <==
Next generation of fcitx
==========================
Fcitx 5 is a generic input method framework released under LGPL-2.1+.

[![Jenkins Build Status](https://img.shields.io/jenkins/s/https/jenkins.fcitx-im.org/job/fcitx5.svg)](https://jenkins.fcitx-im.org/job/fcitx5/)
[![Coverity Scan Status](https://img.shields.io/coverity/scan/9063.svg)](https://scan.coverity.com/projects/fcitx-fcitx5)
[![Documentation](https://codedocs.xyz/fcitx/fcitx5.svg)](https://codedocs.xyz/fcitx/fcitx5/)

* Wiki: [https://fcitx-im.org/](https://fcitx-im.org/)
  - Registration require explicit approval due to the spam, please send an email to the mail list if you do not get approved.
* Discussion:
  - [fcitx [at] googlegroups.com](https://groups.google.com/g/fcitx)
  - [https://github.com/fcitx/fcitx5/discussions](https://github.com/fcitx/fcitx5/discussions)
  - Telegram: https://fcitx-im.org/telegram/captcha.html
  - IRC: [#fcitx [at] libera.chat](https://web.libera.chat/?channels=#fcitx)
* Bug report: [https://github.com/fcitx/fcitx5/issues](https://github.com/fcitx/fcitx5/issues)
  - You can always report any fcitx 5 issue here, it might be transfer to other repos later.
* Translation: [https://explore.transifex.com/fcitx/](https://explore.transifex.com/fcitx/)
  - Do not send pull request for translation updates.
  - The translation will be automatically pushed to git repository nightly, but not vice versa.

[![Packaging status](https://repology.org/badge/vertical-allrepos/fcitx5.svg)](https://repology.org/project/fcitx5/versions)
